==> jc-1.4.0.tar.gz: java/util/zip/ZipOutputStream.h <==
// public class java.util.zip.ZipOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class cae120da050b0377 java_util_zip_ZipOutputStream

// header file dependencies
// @dep_header java_util_zip_DeflaterOutputStream

#include "java/util/zip/DeflaterOutputStream.h"

#ifndef _JC_java_util_zip_ZipOutputStream_H_
#define _JC_java_util_zip_ZipOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_java_util_zip_CRC32$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipOutputStream$sub_refs	_jc_java_util_zip_ZipOutputStream$sub_refs;
typedef struct _jc_java_util_zip_ZipOutputStream$sub_nonrefs	_jc_java_util_zip_ZipOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipOutputStream$refs	_jc_java_util_zip_ZipOutputStream$refs;
typedef struct _jc_java_util_zip_ZipOutputStream$nonrefs	_jc_java_util_zip_ZipOutputStream$nonrefs;
typedef struct _jc_java_util_zip_ZipOutputStream$object	_jc_java_util_zip_ZipOutputStream$object;

typedef struct _jc_java_util_zip_ZipOutputStream$fields_struct	_jc_java_util_zip_ZipOutputStream$fields_struct;
typedef const struct _jc_java_util_zip_ZipOutputStream$vmethods	_jc_java_util_zip_ZipOutputStream$vmethods;
typedef const struct _jc_java_util_zip_ZipOutputStream$vtable	_jc_java_util_zip_ZipOutputStream$vtable;
typedef const struct _jc_java_util_zip_ZipOutputStream$vtype	_jc_java_util_zip_ZipOutputStream$vtype;

// Class fields structure
struct _jc_java_util_zip_ZipOutputStream$fields_struct {
	jint	DEFLATED;
	jint	STORED;
	jint	ZIP__5fDEFLATED__5fVERSION;
	jint	ZIP__5fSTORED__5fVERSION;
};
extern _jc_java_util_zip_ZipOutputStream$fields_struct _jc_java_util_zip_ZipOutputStream$class_fields;

// Constructors
extern void _jc_java_util_zip_ZipOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_java_util_zip_ZipOutputStream$method$closeEntry$9060a01a67213941(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
extern void _jc_java_util_zip_ZipOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
extern void _jc_java_util_zip_ZipOutputStream$method$putNextEntry$8f69a8523d1dfc98(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *);
extern void _jc_java_util_zip_ZipOutputStream$method$setComment$0e61397b52a72bbd(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_zip_ZipOutputStream$method$setLevel$c8e64370e88154b2(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
extern void _jc_java_util_zip_ZipOutputStream$method$setMethod$87a531d32254a04e(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
extern void _jc_java_util_zip_ZipOutputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
extern void _jc_java_util_zip_ZipOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_util_zip_ZipOutputStream$method$writeLeInt$513fe05753c73d77(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
extern void _jc_java_util_zip_ZipOutputStream$method$writeLeShort$c9d073fa689f4123(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$closeEntry$9060a01a67213941;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$putNextEntry$8f69a8523d1dfc98;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setComment$0e61397b52a72bbd;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setLevel$c8e64370e88154b2;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setMethod$87a531d32254a04e;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$write$306a698343ec27e8;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$writeLeInt$513fe05753c73d77;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$writeLeShort$c9d073fa689f4123;

// Virtual methods structure
struct _jc_java_util_zip_ZipOutputStream$vmethods {
	void	(*closeEntry$9060a01a67213941)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
	void	(*putNextEntry$8f69a8523d1dfc98)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *);
	void	(*setComment$0e61397b52a72bbd)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_lang_String$object *);
	void	(*setLevel$c8e64370e88154b2)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
	void	(*setMethod$87a531d32254a04e)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*writeLeInt$513fe05753c73d77)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
	void	(*writeLeShort$c9d073fa689f4123)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint);
};

// Vtable
struct _jc_java_util_zip_ZipOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_ZipOutputStream$vmethods	java_util_zip_ZipOutputStream;
};

// Vtype
struct _jc_java_util_zip_ZipOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipOutputStream$sub_refs {
	struct _jc_java_util_Vector$object	*entries;
	struct _jc_java_util_zip_CRC32$object	*crc;
	struct _jc_java_util_zip_ZipEntry$object	*curEntry;
	_jc_byte_array	*zipComment;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipOutputStream$refs {
    _jc_java_util_zip_ZipOutputStream$sub_refs	java_util_zip_ZipOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipOutputStream$sub_nonrefs {
	jint	curMethod;
	jint	size;
	jint	offset;
	jint	defaultMethod;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_nonrefs	java_util_zip_ZipOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_ZipOutputStream$object {
	_jc_java_util_zip_ZipOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipOutputStream$vtype	*vtype;
	_jc_java_util_zip_ZipOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipOutputStream$vtype _jc_java_util_zip_ZipOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipOutputStream$class_object;

#endif	/* _JC_java_util_zip_ZipOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/ZipOutputStream.h <==
// public class java.util.zip.ZipOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class cae120da050b0377 java_util_zip_ZipOutputStream

// header file dependencies
// @dep_header java_util_zip_DeflaterOutputStream

#include "java/util/zip/DeflaterOutputStream.h"

#ifndef _JC_java_util_zip_ZipOutputStream_H_
#define _JC_java_util_zip_ZipOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_java_util_zip_CRC32$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipOutputStream$sub_refs	_jc_java_util_zip_ZipOutputStream$sub_refs;
typedef struct _jc_java_util_zip_ZipOutputStream$sub_nonrefs	_jc_java_util_zip_ZipOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipOutputStream$refs	_jc_java_util_zip_ZipOutputStream$refs;
typedef struct _jc_java_util_zip_ZipOutputStream$nonrefs	_jc_java_util_zip_ZipOutputStream$nonrefs;
typedef struct _jc_java_util_zip_ZipOutputStream$object	_jc_java_util_zip_ZipOutputStream$object;

typedef struct _jc_java_util_zip_ZipOutputStream$fields_struct	_jc_java_util_zip_ZipOutputStream$fields_struct;
typedef const struct _jc_java_util_zip_ZipOutputStream$vmethods	_jc_java_util_zip_ZipOutputStream$vmethods;
typedef const struct _jc_java_util_zip_ZipOutputStream$vtable	_jc_java_util_zip_ZipOutputStream$vtable;
typedef const struct _jc_java_util_zip_ZipOutputStream$vtype	_jc_java_util_zip_ZipOutputStream$vtype;

// Class fields structure
struct _jc_java_util_zip_ZipOutputStream$fields_struct {
	jint	DEFLATED;
	jint	STORED;
	jint	ZIP__5fDEFLATED__5fVERSION;
	jint	ZIP__5fSTORED__5fVERSION;
};
extern _jc_java_util_zip_ZipOutputStream$fields_struct _jc_java_util_zip_ZipOutputStream$class_fields;

// Constructors
extern void _jc_java_util_zip_ZipOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_zip_ZipOutputStream$method$closeEntry$9060a01a67213941(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$putNextEntry$8f69a8523d1dfc98(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$setComment$0e61397b52a72bbd(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$setLevel$c8e64370e88154b2(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$setMethod$87a531d32254a04e(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$writeLeInt$513fe05753c73d77(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_ZipOutputStream$method$writeLeShort$c9d073fa689f4123(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$closeEntry$9060a01a67213941;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$putNextEntry$8f69a8523d1dfc98;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setComment$0e61397b52a72bbd;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setLevel$c8e64370e88154b2;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$setMethod$87a531d32254a04e;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$write$306a698343ec27e8;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$writeLeInt$513fe05753c73d77;
extern _jc_method _jc_java_util_zip_ZipOutputStream$method_info$writeLeShort$c9d073fa689f4123;

// Virtual methods structure
struct _jc_java_util_zip_ZipOutputStream$vmethods {
	void	(*closeEntry$9060a01a67213941)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
	void	(*putNextEntry$8f69a8523d1dfc98)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *) _JC_JCNI_ATTR;
	void	(*setComment$0e61397b52a72bbd)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setLevel$c8e64370e88154b2)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*setMethod$87a531d32254a04e)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*writeLeInt$513fe05753c73d77)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*writeLeShort$c9d073fa689f4123)(_jc_env *, struct _jc_java_util_zip_ZipOutputStream$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_ZipOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_ZipOutputStream$vmethods	java_util_zip_ZipOutputStream;
};

// Vtype
struct _jc_java_util_zip_ZipOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipOutputStream$sub_refs {
	struct _jc_java_util_Vector$object	*entries;
	struct _jc_java_util_zip_CRC32$object	*crc;
	struct _jc_java_util_zip_ZipEntry$object	*curEntry;
	_jc_byte_array	*zipComment;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipOutputStream$refs {
    _jc_java_util_zip_ZipOutputStream$sub_refs	java_util_zip_ZipOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipOutputStream$sub_nonrefs {
	jint	curMethod;
	jint	size;
	jint	offset;
	jint	defaultMethod;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_nonrefs	java_util_zip_ZipOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_ZipOutputStream$object {
	_jc_java_util_zip_ZipOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipOutputStream$vtype	*vtype;
	_jc_java_util_zip_ZipOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipOutputStream$vtype _jc_java_util_zip_ZipOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipOutputStream$class_object;

#endif	/* _JC_java_util_zip_ZipOutputStream_H_ */
